# <img src='https://0000.us/klatchat/app/files/neon_images/icons/neon_skill.png' card_color="#FF8600" width="50" style="vertical-align:bottom">User Settings

## Summary

Have Neon help you change and control your user settings.

## Description

Neon can help you control your user preference settings via this skill.

## Examples

* Change my units to metric.
* Use imperial units.
* Change my time format to military time.
* Change my time format to twelve hour time.

* Enable hesitation.
* Disable hesitation.
* Use limited responses.
* Use standard responses.

* Enable audio recordings.
* Disable audio recordings.
* Permit transcriptions.
* Disable transcriptions.

* Talk to me faster.
* Talk to me slower.
* Talk to me normally.

* Change my location to Seattle.
* Change my timezone to London.

* Tell me my name.
* Tell me my first name.
* Tell me my last name.

* Tell me my email address.

* Where am I?

* My birthday is...
* My email address is...
* My name is...

* Change my first name to Daniel.
* Change my preferred name to Dan.

* Tell me my language settings.
* I will speak to you in Spanish.
* Speak to me in French.
* Change my primary language to German.
* Change my secondary language to Ukrainian.
* No secondary language.


## Contact Support

Use the [link](https://neongecko.com/ContactUs) or [submit an issue on GitHub](https://help.github.com/en/articles/creating-an-issue)

## Credits
[NeonDaniel](https://github.com/NeonDaniel)
[reginaneon](https://github.com/reginaneon)
[NeonGeckoCom](https://github.com/NeonGeckoCom)

## Category
**Configuration**
Daily

## Tags
#NeonGecko Original
#NeonAI
